# Perceval 'botte secrete' module

After heavy Research and Developpement work the Perceval special technique is now
perfectly implemented in python. 

Use the perceval decorator that way : 


```python
from paysdegalles import perceval

@perceval
def S01E28():
    return everything is possible 
```



